@@ -1,6 +1,6 @@
 package Data::All::IO::Plain;
 
-#   $Id: Plain.pm,v 1.1.2.1.2.1.2.1.6.2.4.1.4.11 2004/05/17 22:28:51 dgrant Exp $
+#   $Id: Plain.pm,v 1.1.2.1.2.1.2.1.6.2.4.1.4.14 2004/05/20 17:45:09 dgrant Exp $
 
 #   BUG: A leading delimiter (i.e. a blank first column) will fuck it up
 
@@ -31,14 +31,17 @@ sub open($)
     unless ($self->is_open())
     {
         warn " -> Opening $path for ", $self->ioconf()->{'perm'};
-        
+        warn " -> path:", join ', ', @{ $self->path() };
+        warn " -> format:", $self->format()->{'type'};
+        warn " -> io:", $self->ioconf->{'type'};
+    
         die("The file: $path does not exist")
             if (($self->ioconf()->{'perm'} eq 'r') && !(-f $path));
     
         #   We create out own filehandle for better read/write control
         my $fh = FileHandle->new($self->create_path(), $self->ioconf()->{'perm'});        
         my $IO = io(-file_handle => $fh, '-tie');
-        
+         
         $IO->autoclose(1);
         
         $self->__IO( $IO );
@@ -55,6 +58,7 @@ sub open($)
 sub close()
 {
     my $self = shift;
+    
     $self->__IO()->close();
     $self->is_open(0);
 }
@@ -107,7 +111,7 @@ sub getrecord_array()
     
     return !wantarray ? $rec_arrayref : @{ $rec_arrayref };
 }
-
+ 
 sub putfields()
 {
     my $self = shift;
@@ -118,7 +122,9 @@ sub putrecord($)
 {
     my $self = shift;
     my $record = shift;
+
     $self->__IO()->print($self->hash_to_record($record));
+    
     return 1;
 }
 
@@ -144,8 +150,15 @@ sub count()
 sub _next()      { $_[0]->__curpos( $_[0]->__curpos() + 1) }
 
 #   $Log: Plain.pm,v $
-#   Revision 1.1.2.1.2.1.2.1.6.2.4.1.4.11  2004/05/17 22:28:51  dgrant
-#   - Misc tidying
+#   Revision 1.1.2.1.2.1.2.1.6.2.4.1.4.14  2004/05/20 17:45:09  dgrant
+#   - Added Data::All::store()
+#   - Some bug fixes
+#
+#   Revision 1.1.2.1.2.1.2.1.6.2.4.1.4.13  2004/05/20 17:43:41  dgrant
+#   *** empty log message ***
+#
+#   Revision 1.1.2.1.2.1.2.1.6.2.4.1.4.12  2004/05/17 23:27:17  dgrant
+#   - Misc cleanup, no changes
 #
 #   Revision 1.1.2.1.2.1.2.1.6.2.4.1.4.10  2004/05/13 00:23:11  dgrant
 #   - Some minor comments added
